#!/bin/bash
#
#  To maintain this only ever edit the
#    control.trunk
#    control.snapshot
#
skip_bzr_clean_check=0
commit_current_state=0
skip_bzr_push=0
unset stop_phase

while [ $# -gt 0 ]
do
	echo "$1"
	case "$1" in
	"--force")
		# Process the last committed state of the tree
		#  this does not cause anything uncommited to be committed.
		skip_bzr_clean_check=1
		;;
	"--no-push")
		skip_bzr_push=1
		;;
	"--commit-current"|"--commit")
		# Commit the existing state of the tree
		commit_current_state=1
		;;
	"--stop-phase")
		shift
		stop_phase="$1"
		;;
	*)
		echo "$0: ERROR invalid option \"$1\"" 1>&2
		exit 1
		;;
	esac

	shift
done

echo "skip_bzr_clean_check=$skip_bzr_clean_check"
echo "commit_current_state=$commit_current_state"
echo "skip_bzr_push=$skip_bzr_push"
echo "stop_phase=$stop_phase"


if [ ! -f "control.trunk" ]
then
	echo "$0: ERROR: control.trunk file does not exist" 1>&2
	exit 1
fi
if [ ! -f "control.snapshot" ]
then
	echo "$0: ERROR: control.snapshot file does not exist" 1>&2
	exit 1
fi

if [ -f "control" ] && [ "control" -nt "control.trunk" ]
then
	echo "$0: ERROR: control is newer than control.trunk, please do not edit control directly" 1>&2
	exit 1
fi
if [ -f "control" ] && [ "control" -nt "control.snapshot" ]
then
	echo "$0: ERROR: control is newer than control.snapshot, please do not edit control directly" 1>&2
	exit 1
fi

if [ $commit_current_state -ne 0 ]
then
	rm -v control FLAG.* $(find -name "*~")
	bzr add -v .
	bzr commit -m "Auto commit current state"
	bzr push
fi

if [ $skip_bzr_clean_check -eq 0 ]
then
	wc=$(bzr status . 2>&1 | wc -l)
	if [ $wc -ne 0 ]
	then
		echo "$0: ERROR: tree has uncommited changes" 1>&2
		bzr status . 1>&2
		echo "$0: ERROR: tree has uncommited changes" 1>&2
		exit 1
	fi
fi

function setup_as_release() {
	cp -av control.trunk control
	rm -f FLAG.*
	touch FLAG.trunk

	sed -e 's/^libqtjambi-snapshot /libqtjambi /' -i changelog
}

function setup_as_snapshot() {
	rm -f FLAG.* control
	cp -av control.snapshot control
	touch FLAG.snapshot

	sed -e 's/^libqtjambi /libqtjambi-snapshot /' -i changelog

	#  This has different ld.so.conf filename to follow package name
	# libqtjambi-jni.install
	for file in \
		ant-qtjambi.install \
		libqtjambi-util.install \
		libqtjambi.install \
		qtjambi-designer.install \
		qtjambi-designer-jni.install \
		qtjambi-examples.install \
		qtjambi-juic.install
	do
		bn=$(basename "$file" ".install")
		if [ -f "$file" ] && ! cmp -s "$file" "${bn}-snapshot.install"
		then
			if [ "${bn}-snapshot.install" -nt "$file" ]
			then
				echo "$0: ERROR: You have edited ${bn}-snapshot.install instead of $file, please undo/merge changes" 1>&2
				exit 1
			fi
			cp -av "$file" "${bn}-snapshot.install"
		fi
	done
}

# Ok now we copy over

# hardy (08.04 LTS)
setup_as_snapshot
# This is not available until maverick (and after)
sed -e '/^[ ]*libqtwebkit-dev.*/d' -i control
# This is not available until lucid (and after)
sed -e '/^[ ]*libqt4-sql-sqlite2.*/d' -i control

sed -e 's/debhelper (>= 7)/debhelper (>= 6)/' -i control
sed -e '/^ gcj-jre-headless,/d' -i control
sed -e '/^ ant-contrib (>= 1.0~b3),/d' -i control
sed -e '/^ phonon,/d' -i control
sed -e '/^ phonon-backend-gstreamer,/d' -i control
sed -e '/^ libqt4-opengl-dev,/d' -i control
sed -e '/^ libqt4-sql-mysql,/d' -i control
sed -e '/^ libqt4-sql-odbc,/d' -i control
sed -e '/^ libqt4-sql-psql,/d' -i control
sed -e '/^ libqt4-sql-sqlite,/d' -i control
sed -e '/^ libqt4-sql-tds,/d' -i control
sed -e 's/ libphonon-dev,/ libphonon-dev/' -i control	# remove trailing comma
sed -e '/^ libjogl-java/d' -i control

sed -e 's/^7$/6/' -i compat


# Reset the full patches/series file
cp -f patches/series.orig patches/series


bzr add control FLAG.snapshot changelog patches/series
bzr commit --unchanged -m "maint/bzr_push.sh Auto copy, commit and push for: control.snapshot (ubuntu/hardy)"
[ "$skip_bzr_push" -eq 0 ] && bzr push
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push  # skipped"
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/hardy/qtjambi-snapshot/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/hardy/qtjambi-snapshot/debian/  # skipped"



# lucid (10.04 LTS)
setup_as_snapshot
# This is not available until maverick (and after)
sed -e '/^[ ]*libqtwebkit-dev.*/d' -i control

bzr add control FLAG.snapshot changelog
bzr commit --unchanged -m "maint/bzr_push.sh Auto copy, commit and push for: control.snapshot (ubuntu/lucid)"
[ "$skip_bzr_push" -eq 0 ] && bzr push
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push  # skipped"
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/lucid/qtjambi-snapshot/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/lucid/qtjambi-snapshot/debian/  # skipped"



# natty (11.04)
setup_as_snapshot
# This workaround is no needed since oneiric (and after)
#sed -e '/^[ ]*gcj-jre-headless.*/d' -i control

bzr add control FLAG.snapshot changelog
bzr commit --unchanged -m "maint/bzr_push.sh Auto copy, commit and push for: control.snapshot (ubuntu/natty)"
[ "$skip_bzr_push" -eq 0 ] && bzr push
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push  # skipped"
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/natty/qtjambi-snapshot/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/natty/qtjambi-snapshot/debian/  # skipped"



# oneiric, precise, quantal, raring, saucy, trusty, utopic, vivid, wily
setup_as_snapshot
# This workaround is no needed since oneiric (and after)
sed -e '/^[ ]*gcj-jre-headless.*/d' -i control
# This is not available in oneiric (and after)
sed -e '/^[ ]*libqt4-sql-sqlite2.*/d' -i control

bzr add control FLAG.snapshot changelog
bzr commit --unchanged -m "maint/bzr_push.sh Auto copy, commit and push for: control.snapshot (snapshot)"
[ "$skip_bzr_push" -eq 0 ] && bzr push
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push  # skipped"
echo MARK000000
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/oneiric/qtjambi-snapshot/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/oneiric/qtjambi-snapshot/debian/  # skipped"
echo MARK00000
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/precise/qtjambi-snapshot/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/precise/qtjambi-snapshot/debian/  # skipped"
echo MARK0000
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/quantal/qtjambi-snapshot/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/quantal/qtjambi-snapshot/debian/  # skipped"
echo MARK000
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/raring/qtjambi-snapshot/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/raring/qtjambi-snapshot/debian/   # skipped"
echo MARK00
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/saucy/qtjambi-snapshot/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/saucy/qtjambi-snapshot/debian/   # skipped"
echo MARK0 -- DIVERGED
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/trusty/qtjambi-snapshot/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/trusty/qtjambi-snapshot/debian/   # skipped"

echo MARK1

cp -f patches/series.orig patches/series
# Remove this as the version of Qt is higher than 4.8.6+ since utopic
sed -e 's/^08_/#08_/' -i patches/series
bzr add patches/series
bzr commit --unchanged -m "maint/bzr_push.sh Auto copy, commit and push for: patches/series (snapshot)"

echo MARK2
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/utopic/qtjambi-snapshot/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/utopic/qtjambi-snapshot/debian/   # skipped"
echo MARK3
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/vivid/qtjambi-snapshot/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/vivid/qtjambi-snapshot/debian/   # skipped"
echo MARK4
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/wily/qtjambi-snapshot/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/wily/qtjambi-snapshot/debian/   # skipped"
echo MARK5



if false
then
# oneiric, precise, quantal, raring, saucy, trusty, utopic, vivid, wily
setup_as_release
# This workaround is no needed since oneiric (and after)
sed -e '/^[ ]*gcj-jre-headless.*/d' -i control
# This is not available in oneiric (and after)
sed -e '/^[ ]*libqt4-sql-sqlite2.*/d' -i control

bzr add control FLAG.trunk changelog
bzr commit --unchanged -m "maint/bzr_push.sh Auto copy, commit and push for: control.trunk (generic)"
[ "$skip_bzr_push" -eq 0 ] && bzr push
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push  # skipped"
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/oneiric/qtjambi/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/oneiric/qtjambi/debian/  # skipped"
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/precise/qtjambi/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/precise/qtjambi/debian/  # skipped"
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/quantal/qtjambi/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/quantal/qtjambi/debian/  # skipped"
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/raring/qtjambi/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/raring/qtjambi/debian/   # skipped"
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/saucy/qtjambi/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/saucy/qtjambi/debian/   # skipped"
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/trusty/qtjambi/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/trusty/qtjambi/debian/   # skipped"
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/utopic/qtjambi/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/utopic/qtjambi/debian/   # skipped"
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/vivid/qtjambi/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/vivid/qtjambi/debian/   # skipped"
[ "$skip_bzr_push" -eq 0 ] && bzr push --create-prefix lp:~qtjambi-community/ubuntu/wily/qtjambi/debian/
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push lp:~qtjambi-community/ubuntu/wily/qtjambi/debian/   # skipped"
fi

echo "All done... IGNORE ERRORS/WARNINGS BELOW..."

rm -f control FLAG.*
[ "$skip_bzr_push" -eq 0 ] && bzr push
[ "$skip_bzr_push" -ne 0 ] &&           echo "bzr push  # skipped"

# Bring back files to the tree is clean again
bzr revert
